@@ -26,8 +26,11 @@
 using namespace std;
 
 
-Downloader::Downloader(const QUrl &url, QString version)
+//Downloader::Downloader(const QUrl &url, QString version)
+Downloader::Downloader(QUrl &url, QString version)
 {
+//url = "ftp://ftp.riken.jp";
+//version="new";
 
     if (url.scheme() != "ftp") {
         QMessageBox::warning(0, tr("Downloader"),
@@ -43,58 +46,59 @@ Downloader::Downloader(const QUrl &url, QString version)
     connect(&ftp, SIGNAL(listInfo(const QUrlInfo &)),
             this, SLOT(listInfo(const QUrlInfo &)));
 
+
 	ftp.connectToHost(url.host(), port);
 	ftp.login();
 	if(url.host() == "ftp.riken.jp"){
-		cout << "test" << endl;
 		if(version == "new4")
-			ftp.cd("Linux/fedora/releases/17/Fedora/i386/iso");
-		if(version == "new3")
 			ftp.cd("Linux/fedora/releases/18/Fedora/i386/iso");
-		if(version == "new2")
+		if(version == "new3")
 			ftp.cd("Linux/fedora/releases/19/Fedora/i386/iso");
-		if(version == "new")
-			ftp.cd("Linux/fedora/releases/20/Fedora/i386/iso");
+		if(version == "new2")
+			ftp.cd("Linux/fedora/releases/20/Fedora/x86_64/iso");
+		if(version == "new"){
+                        ftp.cd("Linux/fedora/releases/21/Workstation/x86_64/iso"); 
+                }
 	}
 	if(url.host() == "mirrors.kernel.org"){
 		if(version == "new4")
-			ftp.cd("fedora/releases/17/Fedora/i386/iso");
+			ftp.cd("fedora/releases/18/Fedora/i386/iso");
 		if(version == "new3")
-			ftp.cd("fedora/releases/18/Fedora/i386/iso/");
+			ftp.cd("fedora/releases/19/Fedora/i386/iso");
 		if(version == "new2")
-			ftp.cd("fedora/releases/19/Fedora/i386/iso/");
+			ftp.cd("fedora/releases/20/Fedora/x86_64/iso");
 		if(version == "new")
-			ftp.cd("fedora/releases/20/Fedora/i386/iso/");
+			ftp.cd("fedora/releases/21/Workstation/x86_64/iso");
 	}
 	if(url.host() == "ftp.uni-kl.de"){
 		if(version == "new4")
-			ftp.cd("pub/linux/fedora/linux/releases/17/Fedora/i386/iso");
-		if(version == "new3")
 			ftp.cd("pub/linux/fedora/linux/releases/18/Fedora/i386/iso");
-		if(version == "new2")
+		if(version == "new3")
 			ftp.cd("pub/linux/fedora/linux/releases/19/Fedora/i386/iso");
+		if(version == "new2")
+			ftp.cd("pub/linux/fedora/linux/releases/20/Fedora/x86_64/iso");
 		if(version == "new")
-			ftp.cd("pub/linux/fedora/linux/releases/20/Fedora/i386/iso");
+			ftp.cd("pub/linux/fedora/linux/releases/21/Workstation/x86_64/iso");
 	}
 	if(url.host() == "ftp.lip6.fr"){
 		if(version == "new4")
-			ftp.cd("pub/linux/distributions/fedora/releases/17/Fedora/i386/iso");
-		if(version == "new3")
 			ftp.cd("pub/linux/distributions/fedora/releases/18/Fedora/i386/iso");
-		if(version == "new2")
+		if(version == "new3")
 			ftp.cd("pub/linux/distributions/fedora/releases/19/Fedora/i386/iso");
+		if(version == "new2")
+			ftp.cd("pub/linux/distributions/fedora/releases/20/Fedora/x86_64/iso");
 		if(version == "new")
-			ftp.cd("pub/linux/distributions/fedora/releases/20/Fedora/i386/iso");
+			ftp.cd("pub/linux/distributions/fedora/releases/21/Workstation/x86_64/iso");
 	}
 	if(url.host() == "mirror.aarnet.edu.au"){
 		if(version == "new4")
-			ftp.cd("pub/fedora/linux/releases/17/Fedora/i386/iso");
-		if(version == "new3")
 			ftp.cd("pub/fedora/linux/releases/18/Fedora/i386/iso");
-		if(version == "new2")
+		if(version == "new3")
 			ftp.cd("pub/fedora/linux/releases/19/Fedora/i386/iso");
+		if(version == "new2")
+			ftp.cd("pub/fedora/linux/releases/20/Fedora/x86_64/iso");
 		if(version == "new")
-			ftp.cd("pub/fedora/linux/releases/20/Fedora/i386/iso");
+			ftp.cd("pub/fedora/linux/releases/21/Workstation/x86_64/iso");
 	}
 	ftp.list();
 }
