@@ -18,9 +18,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
+#include <QLayout>
+#include <QPushButton>
+#include <QLineEdit>
 #include <QLabel>
 
 #include <unistd.h>
