@@ -21,16 +21,14 @@
 #ifndef AUSEARCH_H
 #define AUSEARCH_H
 
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qlabel.h> 
-//added by intrajp
+#include <QDialog>
+#include <QLayout>
+#include <QCheckBox>
+#include <QLabel> 
 #include <QButtonGroup>
 #include <QPushButton>
 #include <QGroupBox>
-
-#include <qradiobutton.h>
+#include <QRadioButton>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 
