@@ -21,15 +21,13 @@
 #ifndef AUSEARCHPROCESS_H
 #define AUSEARCHPROCESS_H
 
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qdir.h> 
-#include <qlabel.h> 
-//#include <q3textedit.h>
+#include <QDialog>
+#include <QLayout>
+#include <QDir> 
+#include <QLabel> 
 #include <QTextEdit>
-#include <q3buttongroup.h>
-#include <qradiobutton.h>
-//Added by qt3to4:
+#include <QButtonGroup>
+#include <QRadioButton>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 
