@@ -18,18 +18,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <q3textedit.h>
-#include <q3process.h>
-#include <qmessagebox.h>
-//Added by qt3to4:
-#include <Q3TextStream>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
-//#include <fstream.h>
+#include <QLayout>
+#include <QLineEdit>
+#include <QPushButton>
+#include <QRadioButton>
+#include <QTextEdit>
+#include <QMessageBox>
+#include <QTextStream>
 #include <fstream>
 
 #include "breakif.h"
@@ -41,7 +36,7 @@ using namespace std;
 BreakIf::BreakIf(QWidget *parent, const char *name): QDialog(parent, name)
 {
 		setCaption(tr("break .if files"));
-		textEdit1 = new Q3TextEdit(this);
+		textEdit1 = new QTextEdit(this);
 		textEdit1->setPaletteBackgroundColor(QColor(174,187,255));
 		closeButton = new QPushButton(tr("&Close"), this);
 		breakifButton = new QPushButton(tr("break .if files"), this);
@@ -51,17 +46,17 @@ BreakIf::BreakIf(QWidget *parent, const char *name): QDialog(parent, name)
 		connect(breakifButton, SIGNAL(clicked()), this, SLOT(breakif_clicked()));
 		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 
-		firstLayout = new Q3VBoxLayout;
-		leftLayout = new Q3HBoxLayout;
+		firstLayout = new QVBoxLayout;
+		leftLayout = new QHBoxLayout;
 
-		rightLayout = new Q3VBoxLayout;
+		rightLayout = new QVBoxLayout;
 		rightLayout->addWidget(breakifButton);
 		rightLayout->addWidget(closeButton);
 
 		firstLayout->addLayout(leftLayout);
 		firstLayout->addWidget(textEdit1);
 
-		mainLayout = new Q3HBoxLayout(this);
+		mainLayout = new QHBoxLayout(this);
 		mainLayout->setMargin(11);
 		mainLayout->setSpacing(6);
 		mainLayout->addLayout(firstLayout);
@@ -69,6 +64,31 @@ BreakIf::BreakIf(QWidget *parent, const char *name): QDialog(parent, name)
 
 		resize(1000,600);
 }
+
+void BreakIf::processExited(int exitCode, QProcess::ExitStatus exitStatus)
+{
+	if ( exitStatus == QProcess::CrashExit )
+	{
+		//QMessageBox::warning( this, tr("Error"), tr("Crashed") );
+		textEdit1->append(tr("Error, Crashed !"));
+		textEdit1->append(tr("\n"));
+	}
+	else if ( exitCode != 0 )
+	{
+		//QMessageBox::warning( this, tr("Error"), tr("Failed") );
+		textEdit1->append(tr("Error, Failed !"));
+		textEdit1->append(tr("\n"));
+	}
+	else
+	{
+		textEdit1->append(tr("breakif  process ended !"));
+		textEdit1->append(tr("\n"));
+        }
+	delete process;
+	process = 0;
+	this->setEnabled(true);
+}
+
 void BreakIf::breakif_clicked()
 {
 		breakif_base_process();
@@ -76,71 +96,24 @@ void BreakIf::breakif_clicked()
 ////////////////////////////////////////////
 void BreakIf::readFromStdout()
 {
-        QByteArray data = process->readStdout();
+        QByteArray data = process->readAllStandardOutput();
         QString text = textEdit1->text() + QString(data);
         textEdit1->setText(text);
 }
-void BreakIf::processExited()
+void BreakIf::updateOutputTextEdit()
 {
-	if(process->normalExit()){
-
-	} else {
-		textEdit1->append(tr("breakif process had an error !"));
-		textEdit1->append(tr("\n"));
-	}
-	delete process;
-	process = 0;
-	this->setEnabled(true);
+	QByteArray data = process->readAllStandardError();
+	QString text = textEdit1->text() + QString(data);
+	textEdit1->setText(text);
 }
 void BreakIf::breakif_base_process()
 {
 	this->setEnabled(false);
-	process = new Q3Process(this);
-	process->addArgument("/usr/share/segatex/raw_if_files/breakif.sh");
+	process = new QProcess(this);
 
-	outputfile_str = "breakif";
-	path = "/usr/share/segatex";
-	forward_slash = "/";
-	outputfile_str = path + forward_slash + outputfile_str;
-	connect(process, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout()));
-	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
-	process->start();
+	connect(process, SIGNAL(readyReadStandardOutput()),this,SLOT(readFromStdout()));
+	connect(process, SIGNAL(readyReadStandardError()),this,SLOT(updateOutputTextEdit()));
+	connect(process, SIGNAL(finished(int, QProcess::ExitStatus)),this,SLOT(processExited(int, QProcess::ExitStatus)));
+	process->start("/usr/share/segatex/raw_if_files/breakif.sh");
 
-	readFromOutputFile();
-}
-
-//this slot should be called from above slot
-void BreakIf::readFromOutputFile()
-{
-	/////////////////////////////////////////////////////////////
-	path = "/usr/share/segatex";
-	/////////////////////////////////////////////////////////////
-	forward_slash = "/";
-	dir.setPath(path);
-	dir_name = dir.absPath();
-	/////////////////////////////////////////////////////////////
-	dir.setFilter( QDir::Files );
-        dir.setSorting( QDir::Name );
-	files = dir.entryList("breakif");
-	/////////////////////////////////////////////////////////////
-	it_d = files.begin();
-	textEdit1->clear();
-		while(it_d != files.end()){
-			name = *it_d;
-			file_interface_name = dir_name + forward_slash + name;
-			QFile file( file_interface_name );
-			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
-				////////////////////////////////////////////
-				while ( !stream.atEnd() ) {
-					line_analized = stream.readLine(); // line of text excluding '\n'
-					textEdit1->append(line_analized);
-				}
-				file.close();
-				++it_d;
-			}else{
-				//do nothing
-			}
-		}
-		textEdit1->setCursorPosition(0,0);
 }
