@@ -18,15 +18,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-#include <qmessagebox.h>
-#include <qworkspace.h>
-//Added by qt3to4:
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
+#include <QLayout>
+#include <QPushButton>
+#include <QLineEdit>
+#include <QTextEdit>
+#include <QMessageBox>
+#include <QWorkspace>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -61,13 +58,13 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 
         fedoraVersionButtonGroup = new Q3ButtonGroup(this);
         fedoraVersionButtonGroup->resize( 150, 70 );
-        new4RadioButton = new QRadioButton(tr("version 17"), fedoraVersionButtonGroup);
+        new4RadioButton = new QRadioButton(tr("version 18"), fedoraVersionButtonGroup);
         new4RadioButton->setGeometry( 10, 10, 300, 20 );
-        new3RadioButton = new QRadioButton(tr("version 18"), fedoraVersionButtonGroup);
+        new3RadioButton = new QRadioButton(tr("version 19"), fedoraVersionButtonGroup);
         new3RadioButton->setGeometry( 10, 30, 300, 20 );
-        new2RadioButton = new QRadioButton(tr("version 19"), fedoraVersionButtonGroup);
+        new2RadioButton = new QRadioButton(tr("version 20"), fedoraVersionButtonGroup);
         new2RadioButton->setGeometry( 10, 50, 300, 20 );
-        newRadioButton = new QRadioButton(tr("version 20"), fedoraVersionButtonGroup);
+        newRadioButton = new QRadioButton(tr("version 21"), fedoraVersionButtonGroup);
         newRadioButton->setGeometry( 10, 70, 300, 20 );
 
 	newRadioButton->setChecked(true);
@@ -82,16 +79,16 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 	closeButton->setDefault(true);
 
-	mainLayout = new Q3VBoxLayout(this);
+	mainLayout = new QVBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	middleLayout = new Q3VBoxLayout;
+	middleLayout = new QVBoxLayout;
 
-	firstLayout = new Q3HBoxLayout;
-	secondLayout = new Q3VBoxLayout;
-	thirdLayout = new Q3VBoxLayout;
+	firstLayout = new QHBoxLayout;
+	secondLayout = new QVBoxLayout;
+	thirdLayout = new QVBoxLayout;
 
-	rightLayout = new Q3HBoxLayout;
+	rightLayout = new QHBoxLayout;
 	
 	secondLayout->addWidget(optionButtonGroup);
 	thirdLayout->addWidget(fedoraVersionButtonGroup);
@@ -105,7 +102,7 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 	middleLayout->addLayout(rightLayout);
 
 
-	footLayout = new Q3HBoxLayout;
+	footLayout = new QHBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -116,9 +113,9 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 
 void Downloader::download_button_clicked()
 {
-	Q3Url url_for_fedora("ftp://mirrors.kernel.org");
+	QUrl url_for_fedora("ftp://mirrors.kernel.org");
 	if(usRadioButton->isChecked()){
-		Q3Url url_for_fedora("ftp://mirrors.kernel.org");
+		QUrl url_for_fedora("ftp://mirrors.kernel.org");
 		url_for_fedora.setPort(21);
 		mirror = 1;
 		if(new4RadioButton->isChecked()){
@@ -135,7 +132,7 @@ void Downloader::download_button_clicked()
 		}
 	}
 	if(jpRadioButton->isChecked()){
-		Q3Url url_for_fedora("ftp://ftp.riken.jp");
+		QUrl url_for_fedora("ftp://ftp.riken.jp");
 		url_for_fedora.setPort(21);
 		mirror = 2;
 		if(new4RadioButton->isChecked()){
@@ -152,7 +149,7 @@ void Downloader::download_button_clicked()
 		}
 	}
 	if(deRadioButton->isChecked()){
-		Q3Url url_for_fedora("ftp://ftp.uni-kl.de");
+		QUrl url_for_fedora("ftp://ftp.uni-kl.de");
 		url_for_fedora.setPort(21);
 		mirror = 2;
 		if(new4RadioButton->isChecked()){
@@ -169,7 +166,7 @@ void Downloader::download_button_clicked()
 		}
 	}
 	if(frRadioButton->isChecked()){
-		Q3Url url_for_fedora("ftp://ftp.lip6.fr");
+		QUrl url_for_fedora("ftp://ftp.lip6.fr");
 		url_for_fedora.setPort(21);
 		mirror = 2;
 		if(new4RadioButton->isChecked()){
@@ -186,7 +183,7 @@ void Downloader::download_button_clicked()
 		}
 	}
 	if(auRadioButton->isChecked()){
-		Q3Url url_for_fedora("ftp://mirror.aarnet.edu.au");
+		QUrl url_for_fedora("ftp://mirror.aarnet.edu.au");
 		url_for_fedora.setPort(21);
 		mirror = 2;
 		if(new4RadioButton->isChecked()){
@@ -204,40 +201,49 @@ void Downloader::download_button_clicked()
 	}
 	downloader_process(url_for_fedora,version);
 }
-void Downloader::downloader_process(const Q3Url &url_for_fedora, QString version)
+void Downloader::downloader_process(const QUrl &url_for_fedora, QString version)
 {
 	this->setEnabled(false);
-	process = new Q3Process(this);
-	process->addArgument("/usr/share/segatex/downloader_program");
-	process->addArgument(url_for_fedora);
-	process->addArgument(version);
+	process = new QProcess(this);
+        //url_str = "/usr/share/segatex/downloader_program " + url_for_fedora + version;
+        url_str = "/usr/share/segatex/downloader " + url_for_fedora + " " + version;
 
-	connect(process, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout()));
-	connect(process, SIGNAL(readyReadStderr()),this,SLOT(updateOutputTextEdit()));
-	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
-	process->start();
+	connect(process, SIGNAL(readyReadStandardOutput()),this,SLOT(readFromStdout()));
+	connect(process, SIGNAL(readyReadStandardError()),this,SLOT(updateOutputTextEdit()));
+	connect(process, SIGNAL(finished(int, QProcess::ExitStatus)),this,SLOT(processExited(int, QProcess::ExitStatus)));
+	process->start(url_str);
 	QMessageBox::warning(0, tr("Downloader Fedora"),
-				tr("Downloading Fedora in your home directory."));
+				tr("Started downloading Fedora in your home directory."));
 }
 void Downloader::updateOutputTextEdit()
 {
-	QByteArray data = process->readStderr();
+	QByteArray data = process->readAllStandardError();
 }
 void Downloader::readFromStdout()
 {
-	QByteArray data = process->readStdout();
+	QByteArray data = process->readAllStandardOutput();
 }
-void Downloader::processExited()
+void Downloader::processExited(int exitCode, QProcess::ExitStatus exitStatus)
 {
-	if(process->normalExit()){
+	if ( exitStatus == QProcess::CrashExit )
+	{
+		//QMessageBox::warning( this, tr("Error"), tr("Crashed") );
 		QMessageBox::warning(0, tr("Downloader Fedora"),
-				     tr("Downloaded files in your home directory."));
-		return;
-	} else {
-		QMessageBox::warning(0, tr("Downloader Fedora"),
-				     tr("Downloader Fedora process had an error"));
+				     tr("Downloader Fedora process crashed."));
 		return;
 	}
+	else if ( exitCode != 0 )
+	{
+		//QMessageBox::warning( this, tr("Error"), tr("Failed") );
+		QMessageBox::warning(0, tr("Downloader Fedora"),
+				     tr("Downloader Fedora process had an error."));
+		return;
+	}
+	else
+	{
+		QMessageBox::warning(0, tr("Downloader Fedora"),
+				     tr("Downloader Fedora process was a success"));
+        }
 	delete process;
 	process = 0;
 	this->setEnabled(true);
