@@ -21,24 +21,26 @@
 #ifndef DOWNLOADER_H
 #define DOWNLOADER_H
 
-#include <qdialog.h>
+#include <QDialog>
 #include <q3ftp.h>
-#include <qstringlist.h>
-#include <q3progressdialog.h>
-#include <qwidget.h>
-#include <qlayout.h>
-#include <qdir.h> 
-#include <qlabel.h> 
-#include <qlineedit.h> 
-#include <q3textedit.h>
-#include <qpushbutton.h>
+//#include <QFtp>
+#include <QStringList>
+#include <QProgressDialog>
+#include <QWidget>
+#include <QLayout>
+#include <QDir> 
+#include <QLabel> 
+#include <QLineEdit> 
+#include <QTextEdit>
+#include <QPushButton>
 #include <q3buttongroup.h>
-#include <qradiobutton.h>
-#include <q3url.h>
-#include <q3process.h>
-//Added by qt3to4:
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
+#include <QRadioButton>
+#include <QUrl>
+#include <QString>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+#include <QProcess>
+#include <QDir>
 
 #include <vector>
 
@@ -52,15 +54,15 @@ signals:
 protected:
 private slots:
 	void download_button_clicked();
-	void downloader_process(const Q3Url &url_for_fedora, QString version);
+	void downloader_process(const QUrl &url_for_fedora, QString version);
 	void updateOutputTextEdit();
 	void readFromStdout();
-	void processExited();
+	void processExited(int, QProcess::ExitStatus);
 public:
 private:
 	int mirror;
 	QString version;
-	Q3Process *process;
+	QProcess *process;
 
 	Q3ButtonGroup *optionButtonGroup;
 	Q3ButtonGroup *fedoraVersionButtonGroup;
@@ -79,13 +81,13 @@ private:
 	QPushButton *downloadButton;
 	QPushButton *closeButton;
 
-	Q3VBoxLayout *mainLayout;
-	Q3VBoxLayout *middleLayout;
-	Q3HBoxLayout *firstLayout;
-	Q3VBoxLayout *secondLayout;
-	Q3VBoxLayout *thirdLayout;
-	Q3HBoxLayout *rightLayout;
-	Q3HBoxLayout *footLayout;
+	QVBoxLayout *mainLayout;
+	QVBoxLayout *middleLayout;
+	QHBoxLayout *firstLayout;
+	QVBoxLayout *secondLayout;
+	QVBoxLayout *thirdLayout;
+	QHBoxLayout *rightLayout;
+	QHBoxLayout *footLayout;
 
         QDir dir;
         QString path;
@@ -106,6 +108,7 @@ private:
         QString semanageEditLineEdit_str;
         QString semanageEditLineEdit_str_pp;
         QString restorecon_str;
+        QString url_str;
 
 	Q3Ftp ftp;
 	std::vector<QFile *> openedFiles;
