@@ -52,22 +52,18 @@
  **
  ****************************************************************************/
 #include <QtGui>
-
-#include <qaction.h>
-#include <qapplication.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qmenubar.h>
-#include <qmessagebox.h>
-#include <qstatusbar.h>
-#include <qworkspace.h>
-//newly added
-#include <qsplitter.h>
-#include <qpushbutton.h>
-#include <q3textedit.h>
-//Added by qt3to4:
+#include <QAction>
+#include <QApplication>
+#include <QLabel>
+#include <QLayout>
+#include <QMenuBar>
+#include <QMessageBox>
+#include <QStatusBar>
+#include <QWorkspace>
+#include <QSplitter>
+#include <QPushButton>
+#include <QTextEdit>
 #include <QPixmap>
-///#include <Q3PopupMenu>//replaced
 #include <QMenu>
 #include <QCloseEvent>
 
@@ -180,7 +176,7 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-8.500"));
+	setWindowTitle(tr("segatex-8.600"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
 }
@@ -637,7 +633,7 @@ void MainWindow::paste()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-8.500</h2>"
+		tr("<h2>segatex-8.600</h2>"
 		"<p>Copyright &copy; 2007-2014"
 		"<p>Shintaro Fujiwara."
 		"<p><a href=\"http://sourceforge.net/projects/segatex\">segatex</a> is a SELinux tool"
