@@ -18,16 +18,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <q3textedit.h>
-//Added by qt3to4:
+#include <QLayout>
+#include <QCheckBox>
+#include <QLineEdit>
+#include <QPushButton>
+#include <QRadioButton>
+#include <QTextEdit>
 #include <Q3TextStream>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
 
 #include "sqlrefpolicy.h"
 #include "segatex_core2_process.h"
@@ -40,7 +37,7 @@ SegatexCore2Process::SegatexCore2Process(QWidget *parent, const char *name): QDi
 {
 
 	setCaption(tr("mypolicybysegatex"));
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	//textEdit1->setPaletteBackgroundColor(QColor(100,255,100));
 	closeButton = new QPushButton(tr("close"), this);
 //test
@@ -60,10 +57,10 @@ SegatexCore2Process::SegatexCore2Process(QWidget *parent, const char *name): QDi
 	connect(prevDeniedMessageButton, SIGNAL(clicked()), this, SLOT(prev_denied_message_button_clicked()));
 //end-test
 
-	Q3VBoxLayout *headLayout = new Q3VBoxLayout;
+	headLayout = new QVBoxLayout;
 	headLayout->addWidget(textEdit1);
 
-	Q3HBoxLayout *footLayout = new Q3HBoxLayout;
+	footLayout = new QHBoxLayout;
 	footLayout->addStretch(1);
 //test
 	footLayout->addWidget(prevDeniedMessageButton);
@@ -71,7 +68,7 @@ SegatexCore2Process::SegatexCore2Process(QWidget *parent, const char *name): QDi
 //end-test
 	footLayout->addWidget(closeButton);
 
-	Q3VBoxLayout *mainLayout = new Q3VBoxLayout(this);
+	mainLayout = new QVBoxLayout(this);
 	mainLayout->setMargin(11);
 	mainLayout->setSpacing(6);
 	mainLayout->addLayout(headLayout);
