@@ -22,14 +22,17 @@
 #define SEGATEXCORE2PROCESS_H
 
 #include <QStringList>
-#include <qfile.h>
-#include <q3textstream.h>
-#include <qregexp.h>
-#include <qdir.h>
-#include <q3textedit.h>
-#include <qsplitter.h>
+#include <QFile>
+#include <QTextStream>
+#include <QRegExp>
+#include <QDir>
+#include <QTextEdit>
+#include <QSplitter>
 #include <QSqlTableModel>
 #include <QTableView>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+
 #include "segatex_core.h" 
 
 class Sqlrefpolicy;
@@ -56,7 +59,7 @@ private slots:
 	void sqlrefpolicy_select(const QList<QString> &, const QList<QString> &, const QList<QString> &, const QList<QString> &);
 private:
 	QPushButton *closeButton;
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 	SegatexCore *segatex_core2_on;
 	SegatexCore2Process *segatex_core2_process;
 	
@@ -160,6 +163,9 @@ private:
 	QList<QString> lines_log_str_tcontext;
 	QList<QString> lines_log_str_tclass;
 	QList<QString> lines_log_str_access_vector;
+        QVBoxLayout *headLayout;
+        QHBoxLayout *footLayout;
+        QVBoxLayout *mainLayout;
 };
 
 #endif
