@@ -22,11 +22,11 @@
 #define SEGATEXGETPIDCON_H
 
 #include <QPushButton>
-#include <qdialog.h>
-#include <qdir.h>
-#include <q3textedit.h>
-#include <Q3VBoxLayout>
-#include <Q3HBoxLayout>
+#include <QDialog>
+#include <QDir>
+#include <QTextEdit>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 
 #include <selinux/selinux.h>
 
@@ -45,10 +45,10 @@ signals:
 protected:
 private slots:
 private:
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 	QPushButton *closeButton;
-	Q3VBoxLayout *mainLayout;
-	Q3HBoxLayout *footLayout;
+	QVBoxLayout *mainLayout;
+	QHBoxLayout *footLayout;
 
 	QString seuser_string;
 	QString seuser_str;
