@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qmessagebox.h>
+#include <QMessageBox>
 
 #include "segatex_getseuserbyname.h"
 #include "segatex_getseuserbyname_process.h"
