@@ -21,6 +21,10 @@
 #ifndef SEGATEXYUMPROCESS_H
 #define SEGATEXYUMPROCESS_H
 
+#include <QProcess> 
+#include <QVBoxLayout> 
+#include <QHBoxLayout> 
+
 #include "segatex_yum.h" 
 
 
@@ -40,16 +44,19 @@ private slots:
 	void yum_install_base_process();
 	void yum_update_base_process();
 	void readFromStdout();
-	void readFromStdout1();
 	void updateOutputTextEdit();
+        void processExited(int, QProcess::ExitStatus);
 	void updateOutputTextEdit1();
-	void processExited();
-	void processExited1();
+	void readFromStdout1();
+        void processExited1(int, QProcess::ExitStatus);
 private:
 	QPushButton *closeButton;
-	Q3TextEdit *textEdit1;
-	Q3Process *process;
-	Q3Process *process1;
+	QTextEdit *textEdit1;
+	QProcess *process;
+	QProcess *process1;
+	QVBoxLayout *headLayout;
+	QHBoxLayout *footLayout;
+	QVBoxLayout *mainLayout;
 	SegatexYum *selinux_yum_on;
 	SegatexYumProcess *selinux_yum_process;
 	SegatexYumProcess *selinux_yum_process_progress;
