@@ -18,16 +18,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <q3buttongroup.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-//Added by qt3to4:
-#include <Q3TextStream>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
+#include <QLayout>
+#include <QPushButton>
+#include <QRadioButton>
+#include <QButtonGroup>
+#include <QLineEdit>
+#include <QTextEdit>
+#include <QTextStream>
 #include <QLabel>
 
 #include <unistd.h>
@@ -44,7 +41,7 @@ using namespace std;
 //default constructor
 SemanageCoreBooleanProcess::SemanageCoreBooleanProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
 
 	semanageEditLabel = new QLabel(tr("Boolean:"), this );
@@ -211,7 +208,7 @@ void SemanageCoreBooleanProcess::readFromOutputFile()
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
 			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
+				QTextStream stream( &file );
 				////////////////////////////////////////////
 				//int i,j,k,l,m,n;	
 				if(order_x == 1)
@@ -221,7 +218,7 @@ void SemanageCoreBooleanProcess::readFromOutputFile()
 					line_analized = stream.readLine(); // line of text excluding '\n'
 					textEdit1->append(line_analized);
 				}
-				textEdit1->setCursorPosition(0,0);
+				//textEdit1->setCursorPosition(0,0);
 				//file.close();
 				order_x++;
 				++it_d;
