@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2013 Shintaro Fujiwara 
+ * Copyright (C) 2007-2014 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qpushbutton.h>
-#include <q3process.h>
-//Added by qt3to4:
-#include <Q3TextStream>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
+#include <QPushButton>
+#include <QTextStream>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -40,7 +38,7 @@ using namespace std;
 SesearchProcess::SesearchProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Sesearch Process"));
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
         textEdit1->resize( 600, 100 );
 
@@ -49,9 +47,9 @@ SesearchProcess::SesearchProcess(QWidget *parent, const char *name): QDialog(par
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 	closeButton->setDefault(true);
 
-	mainLayout = new Q3VBoxLayout(this);
-	upperLayout = new Q3VBoxLayout;
-	footLayout = new Q3HBoxLayout;
+	mainLayout = new QVBoxLayout(this);
+	upperLayout = new QVBoxLayout;
+	footLayout = new QHBoxLayout;
 	
 	mainLayout->setMargin(11);
 	upperLayout->addWidget(textEdit1);
@@ -117,18 +115,18 @@ void SesearchProcess::readFromOutputFile(QString sesearch_str_pp_str)
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
 			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
+				QTextStream stream( &file );
 				////////////////////////////////////////////
 				//int i,j,k,l,m,n;	
 				if(order_x == 1)
-					sesearch_str_pp_str_echo = "################  " +sesearch_str_pp_str + "  #################";
+					sesearch_str_pp_str_echo = "################  " + sesearch_str_pp_str + "  #################";
                                         textEdit1->append(sesearch_str_pp_str_echo);
 					textEdit1->append("");
 				while ( !stream.atEnd() ) {
 					line_analized = stream.readLine(); // line of text excluding '\n'
 					textEdit1->append(line_analized);
 				}
-				textEdit1->setCursorPosition(0,0);
+				//textEdit1->setCursorPosition(0,0);
 				file.close();
 				order_x++;
 				++it_d;
